/// <reference lib="es5" />
/// <reference lib="es2015.core" />
import './promise.finally';
export declare type Omit<T, K> = Pick<T, Exclude<keyof T, K>>;
interface ObjectLike {
    [key: string]: string | number | boolean | null | undefined;
}
interface ArrayLike {
    [key: number]: string | number | boolean | null | undefined;
}
/**
 * 参数类型
 */
export declare type ParamsType = ObjectLike | ArrayLike | Record<string | number, string | number | boolean | null | undefined> | ((string | number | boolean)[]);
/**
 * 构建url参数
 * /users/{id} ==> /users/123
 * @param url - url 相对地址或者绝对地址
 * @param params - Obejct 键值对 替换的参数列表
 * @param baseUrl - 根目录，当url以https://或者http://开头忽略此参数
 * @returns 完整参数URL
 */
export declare function buildParams(url: string, params?: ParamsType, baseUrl?: string): string;
/**
 * 合并公共配置
 * @param data - new configuration for wechat operation
 * @param options - default global configuration
 * @param extendKeys - key need copy to data
 */
export declare function getCommonOptions<T extends {
    [key: string]: any;
}>(data: T, options: {
    [key: string]: any;
}, extendKeys: (keyof T)[]): T;
export {};
//# sourceMappingURL=index.d.ts.map